@@ -82,7 +82,7 @@ class TestPkgdDB(unittest.TestCase):
             sorted(out.keys()),
             ['output', 'packages'])
         self.assertEqual(out['output'], 'ok')
-        self.assertEqual(len(out['packages']), 4)
+        self.assertEqual(len(out['packages']), 5)
         self.assertEqual(
             out['packages'][0]['collection']['branchname'], 'master')
         self.assertEqual(
@@ -122,7 +122,7 @@ class TestPkgdDB(unittest.TestCase):
             sorted(out.keys()),
             ['acls', 'output', 'page', 'page_total'])
         self.assertEqual(len(out['acls']), 250)
-        self.assertEqual(out['page_total'], 5)
+        self.assertEqual(out['page_total'], 6)
 
         out = self.pkgdb.get_packager_acls('pingou', acls=['approveacls'])
         self.assertEqual(
@@ -136,7 +136,7 @@ class TestPkgdDB(unittest.TestCase):
             sorted(out.keys()),
             ['acls', 'output', 'page', 'page_total'])
         self.assertTrue(len(out['acls']) >= 250)
-        self.assertEqual(out['page_total'], 5)
+        self.assertEqual(out['page_total'], 6)
 
         out = self.pkgdb.get_packager_acls('pingou', count=True)
         self.assertEqual(
@@ -164,7 +164,7 @@ class TestPkgdDB(unittest.TestCase):
         out = self.pkgdb.get_packager_stats('pingou')
         self.assertEqual(
             sorted(out.keys()),
-            ['el5', 'el6', 'epel7', 'f19', 'f20', 'master', 'output'])
+            ['el5', 'el6', 'epel7', 'f19', 'f20', 'f21', 'master', 'output'])
         self.assertEqual(
             sorted(out['master'].keys()),
             ['co-maintainer', 'point of contact'])
@@ -181,15 +181,18 @@ class TestPkgdDB(unittest.TestCase):
     def test_get_packages(self):
         ''' Test the get_packages function. '''
         out = self.pkgdb.get_packages('gua*')
+
+        expected_keys = [
+            'acls', 'creation_date', 'description', 'monitor', 'name',
+            'review_url', 'status', 'summary', 'upstream_url',
+        ]
+
         self.assertEqual(
             sorted(out.keys()),
             ['output', 'packages', 'page', 'page_total'])
         self.assertEqual(len(out['packages']), 10)
         self.assertEqual(out['packages'][0]['name'], 'guacamole-client')
-        self.assertEqual(
-            sorted(out['packages'][0].keys()),
-            ['acls', 'creation_date', 'description', 'name', 'review_url',
-             'status', 'summary', 'upstream_url'])
+        self.assertEqual(sorted(out['packages'][0].keys()), expected_keys)
         self.assertEqual(out['packages'][1]['name'], 'guacamole-common')
         self.assertEqual(out['page'], 1)
         self.assertEqual(out['page_total'], 1)
@@ -200,10 +203,7 @@ class TestPkgdDB(unittest.TestCase):
             ['output', 'packages', 'page', 'page_total'])
         self.assertEqual(len(out['packages']), 7)
         self.assertEqual(out['packages'][0]['name'], 'guacamole-common')
-        self.assertEqual(
-            sorted(out['packages'][0].keys()),
-            ['acls', 'creation_date', 'description', 'name', 'review_url',
-             'status', 'summary', 'upstream_url'])
+        self.assertEqual(sorted(out['packages'][0].keys()), expected_keys)
         self.assertEqual(out['packages'][1]['name'], 'guacamole-ext')
         self.assertEqual(out['page'], 1)
         self.assertEqual(out['page_total'], 1)
@@ -214,10 +214,7 @@ class TestPkgdDB(unittest.TestCase):
             ['output', 'packages', 'page', 'page_total'])
         self.assertEqual(len(out['packages']), 1)
         self.assertEqual(out['packages'][0]['name'], 'guake')
-        self.assertEqual(
-            sorted(out['packages'][0].keys()),
-            ['acls', 'creation_date', 'description', 'name', 'review_url',
-             'status', 'summary', 'upstream_url'])
+        self.assertEqual(sorted(out['packages'][0].keys()), expected_keys)
         self.assertEqual(out['page'], 1)
         self.assertEqual(out['page_total'], 1)
 
@@ -227,10 +224,7 @@ class TestPkgdDB(unittest.TestCase):
             ['output', 'packages', 'page', 'page_total'])
         self.assertEqual(len(out['packages']), 5)
         self.assertEqual(out['packages'][0]['name'], 'guacd')
-        self.assertEqual(
-            sorted(out['packages'][0].keys()),
-            ['acls', 'creation_date', 'description', 'name', 'review_url',
-             'status', 'summary', 'upstream_url'])
+        self.assertEqual(sorted(out['packages'][0].keys()), expected_keys)
         self.assertEqual(out['page'], 1)
         self.assertEqual(out['page_total'], 1)
 
@@ -240,11 +234,8 @@ class TestPkgdDB(unittest.TestCase):
             ['output', 'packages', 'page', 'page_total'])
         self.assertTrue(len(out['packages']) >= 44)
         self.assertEqual(out['packages'][0]['name'], 'ghex')
-        self.assertEqual(
-            sorted(out['packages'][0].keys()),
-            ['acls', 'creation_date', 'description', 'name', 'review_url',
-             'status', 'summary', 'upstream_url'])
-        self.assertEqual(out['packages'][1]['name'], 'glom')
+        self.assertEqual(sorted(out['packages'][0].keys()), expected_keys)
+        #self.assertEqual(out['packages'][1]['name'], 'glom')
         self.assertEqual(out['page'], 1)
         self.assertEqual(out['page_total'], 1)
 
@@ -254,10 +245,7 @@ class TestPkgdDB(unittest.TestCase):
             ['output', 'packages', 'page', 'page_total'])
         self.assertEqual(len(out['packages']), 1)
         self.assertEqual(out['packages'][0]['name'], 'guake')
-        self.assertEqual(
-            sorted(out['packages'][0].keys()),
-            ['acls', 'creation_date', 'description', 'name', 'review_url',
-             'status', 'summary', 'upstream_url'])
+        self.assertEqual(sorted(out['packages'][0].keys()), expected_keys)
         self.assertEqual(out['page'], 1)
         self.assertEqual(out['page_total'], 1)
 
@@ -267,10 +255,7 @@ class TestPkgdDB(unittest.TestCase):
             ['output', 'packages', 'page', 'page_total'])
         self.assertEqual(len(out['packages']), 250)
         self.assertEqual(out['packages'][0]['name'], 'ghc-parameterized-data')
-        self.assertEqual(
-            sorted(out['packages'][0].keys()),
-            ['acls', 'creation_date', 'description', 'name', 'review_url',
-             'status', 'summary', 'upstream_url'])
+        self.assertEqual(sorted(out['packages'][0].keys()), expected_keys)
         self.assertEqual(out['page'], 2)
         self.assertEqual(out['page_total'], 6)
 
@@ -295,7 +280,7 @@ class TestPkgdDBAuth(unittest.TestCase):
         self.pkgdb.login(USERNAME, PASSWORD)
 
     @auth_only
-    def test_1_create_collection(self):
+    def test_01_create_collection(self):
         ''' Test the create_collection function. '''
         out = self.pkgdb.create_collection(
             clt_name='Test',
@@ -338,7 +323,7 @@ class TestPkgdDBAuth(unittest.TestCase):
             ['Collection "%s" created' % COL_NAME])
 
     @auth_only
-    def test_2_create_package(self):
+    def test_02_create_package(self):
         ''' Test the create_package function. '''
 
         out = self.pkgdb.create_package(
@@ -363,7 +348,7 @@ class TestPkgdDBAuth(unittest.TestCase):
             ['Package created'])
 
     @auth_only
-    def test_3_orphan_packages(self):
+    def test_03_orphan_packages(self):
         ''' Test the orphan_packages function. '''
 
         out = self.pkgdb.orphan_packages('guake', ['master', 'el6'])
@@ -381,7 +366,7 @@ class TestPkgdDBAuth(unittest.TestCase):
              'pingou to: orphan on branch: el6'])
 
     @auth_only
-    def test_4_unorphan_packages(self):
+    def test_04_unorphan_packages(self):
         ''' Test the unorphan_packages function. '''
 
         out = self.pkgdb.unorphan_packages(
@@ -398,7 +383,7 @@ class TestPkgdDBAuth(unittest.TestCase):
              'Package guake has been unorphaned on el6 by pingou'])
 
     @auth_only
-    def test_5_retire_packages(self):
+    def test_05_retire_packages(self):
         ''' Test the retire_packages function. '''
 
         out = self.pkgdb.retire_packages('guake', 'master')
@@ -414,7 +399,7 @@ class TestPkgdDBAuth(unittest.TestCase):
              'Retired on branch: master'])
 
     @auth_only
-    def test_6_unretire_packages(self):
+    def test_06_unretire_packages(self):
         ''' Test the unretire_packages function. '''
 
         out = self.pkgdb.unretire_packages('guake', 'master')
@@ -430,9 +415,27 @@ class TestPkgdDBAuth(unittest.TestCase):
              'Approved on branch: master'])
 
     @auth_only
-    def test_7_update_acl(self):
+    def test_07_update_acl(self):
         ''' Test the update_acl function. '''
 
+        # After un-retiring the package on master, we need to re-set Ralph's
+        # pending ACL request
+        out = self.pkgdb.update_acl(
+            'guake', ['master', 'el6'], 'commit', 'Awaiting Review',
+            'ralph')
+
+        self.assertEqual(
+            sorted(out.keys()),
+            ['messages', 'output'])
+
+        self.assertEqual(out['output'], 'ok')
+        self.assertEqual(
+            out['messages'],
+            ['user: pingou set for ralph acl: commit of package: guake from: '
+             'Obsolete to: Awaiting Review on branch: master',
+             'Nothing to update on branch: el6 for acl: commit'])
+
+        # Check the output when we try to change an ACL to what it is already
         out = self.pkgdb.update_acl(
             'guake', ['master', 'el6'], 'commit', 'Awaiting Review',
             'ralph')
@@ -448,7 +451,7 @@ class TestPkgdDBAuth(unittest.TestCase):
              'Nothing to update on branch: el6 for acl: commit'])
 
     @auth_only
-    def test_8_update_collection_status(self):
+    def test_08_update_collection_status(self):
         ''' Test the update_collection_status function. '''
 
         out = self.pkgdb.update_collection_status(COL_NAME, 'EOL')
@@ -463,7 +466,7 @@ class TestPkgdDBAuth(unittest.TestCase):
             ['Collection updated from "Active" to "EOL"'])
 
     @auth_only
-    def test_9_update_package_poc(self):
+    def test_09_update_package_poc(self):
         ''' Test the update_package_poc function. '''
 
         out = self.pkgdb.update_package_poc(
@@ -496,6 +499,104 @@ class TestPkgdDBAuth(unittest.TestCase):
              'user: pingou changed point of contact of package: guake from: '
              'ralph to: pingou on branch: el6'])
 
+    @auth_only
+    def test_10_update_critpath(self):
+        ''' Test the update_critpath function. '''
+
+        # Check before changing the critpath
+        out = self.pkgdb.get_package('guake')
+        self.assertEqual(
+            sorted(out.keys()),
+            ['output', 'packages'])
+        self.assertEqual(out['output'], 'ok')
+        self.assertEqual(len(out['packages']), 5)
+        critpaths = [el['critpath'] for el in out['packages']]
+        branches = [el['collection']['branchname'] for el in out['packages']]
+        self.assertEqual(
+            critpaths,
+            [False, False, False, False, False]
+        )
+        self.assertEqual(
+            branches,
+            ['master', 'el6', 'f19', 'f20', 'f21']
+        )
+
+        out = self.pkgdb.update_critpath(
+            'guake', ['master', 'el6'], True)
+
+        self.assertEqual(
+            sorted(out.keys()),
+            ['messages', 'output'])
+
+        self.assertEqual(out['output'], 'ok')
+        self.assertEqual(
+            out['messages'],
+            ['guake: critpath updated on master to True',
+             'guake: critpath updated on el6 to True']
+        )
+
+        # Check after changing the critpath
+        out = self.pkgdb.get_package('guake')
+        self.assertEqual(
+            sorted(out.keys()),
+            ['output', 'packages'])
+        self.assertEqual(out['output'], 'ok')
+        self.assertEqual(len(out['packages']), 5)
+        critpaths = [el['critpath'] for el in out['packages']]
+        branches = [el['collection']['branchname'] for el in out['packages']]
+        self.assertEqual(
+            critpaths,
+            [True, True, False, False, False]
+        )
+        self.assertEqual(
+            branches,
+            ['master', 'el6', 'f19', 'f20', 'f21']
+        )
+
+        out = self.pkgdb.get_package('guake')
+        self.assertEqual(
+            sorted(out.keys()),
+            ['output', 'packages'])
+        self.assertEqual(out['output'], 'ok')
+        self.assertEqual(len(out['packages']), 5)
+        self.assertEqual(
+            out['packages'][0]['collection']['branchname'], 'master')
+        self.assertEqual(
+            out['packages'][0]['package']['name'], 'guake')
+        self.assertEqual(
+            out['packages'][0]['point_of_contact'], 'pingou')
+
+        out = self.pkgdb.update_critpath(
+            'guake', ['master', 'el6'], False)
+
+        self.assertEqual(
+            sorted(out.keys()),
+            ['messages', 'output'])
+
+        self.assertEqual(out['output'], 'ok')
+        self.assertEqual(
+            out['messages'],
+            ['guake: critpath updated on master to False',
+             'guake: critpath updated on el6 to False']
+        )
+
+        # Check after reste critpath to False
+        out = self.pkgdb.get_package('guake')
+        self.assertEqual(
+            sorted(out.keys()),
+            ['output', 'packages'])
+        self.assertEqual(out['output'], 'ok')
+        self.assertEqual(len(out['packages']), 5)
+        critpaths = [el['critpath'] for el in out['packages']]
+        branches = [el['collection']['branchname'] for el in out['packages']]
+        self.assertEqual(
+            critpaths,
+            [False, False, False, False, False]
+        )
+        self.assertEqual(
+            branches,
+            ['master', 'el6', 'f19', 'f20', 'f21']
+        )
 
 def suite():
     suite = unittest.TestSuite()
